@@ -10,7 +10,6 @@ from hypothesis.strategies import integers
 
 from utilities.datetime import TODAY_UTC
 from utilities.hypothesis import temp_paths
-from utilities.pathvalidate import valid_path
 from utilities.pytest import skipif_windows
 from utilities.scripts.clean_dir import main
 from utilities.scripts.clean_dir.classes import Config
@@ -21,7 +20,7 @@ class TestCleanDir:
 
     @skipif_windows
     def test_file(self, *, tmp_path: Path) -> None:
-        valid_path(tmp_path, "file").touch()
+        Path(tmp_path, "file").touch()
         runner = CliRunner()
         args = ["--path", str(tmp_path)]
         with freeze_time(TODAY_UTC + self.timedelta):
@@ -30,7 +29,7 @@ class TestCleanDir:
 
     @skipif_windows
     def test_dir_to_remove(self, *, tmp_path: Path) -> None:
-        valid_path(tmp_path, "dir").mkdir()
+        Path(tmp_path, "dir").mkdir()
         runner = CliRunner()
         args = ["--path", str(tmp_path)]
         result = runner.invoke(main, args)
@@ -38,9 +37,9 @@ class TestCleanDir:
 
     @skipif_windows
     def test_dir_to_retain(self, *, tmp_path: Path) -> None:
-        dir_ = valid_path(tmp_path, "dir")
+        dir_ = Path(tmp_path, "dir")
         dir_.mkdir()
-        valid_path(dir_, "file").touch()
+        Path(dir_, "file").touch()
         runner = CliRunner()
         args = ["--path", str(tmp_path)]
         result = runner.invoke(main, args)
@@ -48,9 +47,9 @@ class TestCleanDir:
 
     @skipif_windows
     def test_symlink(self, *, tmp_path: Path) -> None:
-        file = valid_path(tmp_path, "file")
+        file = Path(tmp_path, "file")
         file.touch()
-        valid_path(tmp_path, "second").symlink_to(file)
+        Path(tmp_path, "second").symlink_to(file)
         runner = CliRunner()
         args = ["--path", str(tmp_path)]
         with freeze_time(TODAY_UTC + self.timedelta):
@@ -60,7 +59,7 @@ class TestCleanDir:
     @skipif_windows
     @given(root=temp_paths(), chunk_size=integers(1, 10))
     def test_chunk_size(self, *, root: Path, chunk_size: int) -> None:
-        valid_path(root, "file").touch()
+        Path(root, "file").touch()
         runner = CliRunner()
         args = ["--path", str(root), "--chunk-size", str(chunk_size)]
         with freeze_time(TODAY_UTC + self.timedelta):
@@ -69,7 +68,7 @@ class TestCleanDir:
 
     @skipif_windows
     def test_dry_run(self, *, tmp_path: Path) -> None:
-        valid_path(tmp_path, "file").touch()
+        Path(tmp_path, "file").touch()
         runner = CliRunner()
         args = ["--path", str(tmp_path), "--dry-run"]
         with freeze_time(TODAY_UTC + self.timedelta):
