@@ -1,20 +1,23 @@
 from __future__ import annotations
 
 from csv import writer
-from pathlib import Path
+from typing import TYPE_CHECKING
 
 from click.testing import CliRunner
 from pytest import fixture
 
-from utilities.pathvalidate import valid_path
+from utilities.pathlib import ensure_path
 from utilities.platform import IS_WINDOWS
 from utilities.scripts.csv_to_markdown import _csv_to_markdown, main
 from utilities.text import strip_and_dedent
 
+if TYPE_CHECKING:
+    from pathlib import Path
 
-@fixture()
+
+@fixture
 def path_csv(*, tmp_path: Path) -> Path:
-    path = valid_path(tmp_path, "input.csv")
+    path = ensure_path(tmp_path, "input.csv")
     with path.open(mode="w", newline="" if IS_WINDOWS else None) as fh:
         csv_writer = writer(fh)
         csv_writer.writerow(["Foo", "Bar"])
