@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from pathlib import Path
+from typing import TYPE_CHECKING
 
 from click.testing import CliRunner
 from hypothesis import given
@@ -10,6 +10,9 @@ from utilities.hypothesis import text_ascii
 from utilities.pathlib import temp_cwd
 from utilities.scripts.luigi_server import _get_args, main
 
+if TYPE_CHECKING:
+    from pathlib import Path
+
 
 class TestLuigiServer:
     @given(
