@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from pathlib import Path
+from typing import TYPE_CHECKING
 
 from click.testing import CliRunner
 from hypothesis import given
@@ -8,19 +8,21 @@ from hypothesis.strategies import integers
 from pytest import raises
 
 from utilities.hypothesis import temp_paths, text_ascii
-from utilities.pathlib import temp_cwd
-from utilities.pathvalidate import valid_path
+from utilities.pathlib import ensure_path, temp_cwd
 from utilities.scripts.pypi_server import _check_password_file, _get_args, main
 
+if TYPE_CHECKING:
+    from pathlib import Path
+
 
 class TestPypiServer:
     def test_check_password_file_success(self, *, tmp_path: Path) -> None:
-        (path_password := valid_path(tmp_path, "password")).touch()
+        (path_password := ensure_path(tmp_path, "password")).touch()
         _check_password_file(path_password=path_password)
 
     def test_check_password_file_error(self, *, tmp_path: Path) -> None:
         with raises(FileNotFoundError):
-            _check_password_file(path_password=valid_path(tmp_path, "password"))
+            _check_password_file(path_password=ensure_path(tmp_path, "password"))
 
     @given(
         port=integers(),
@@ -33,13 +35,13 @@ class TestPypiServer:
     ) -> None:
         _ = _get_args(
             port=port,
-            path_password=valid_path(root, password),
-            path_packages=valid_path(root, packages),
+            path_password=ensure_path(root, password),
+            path_packages=ensure_path(root, packages),
         )
 
     def test_dry_run(self, *, tmp_path: Path) -> None:
         with temp_cwd(tmp_path):
-            path = valid_path("password")
+            path = ensure_path("password")
             path.touch()
             runner = CliRunner()
             args = ["--path-password", str(path), "--dry-run"]
