@@ -1,16 +1,20 @@
 from __future__ import annotations
 
 from operator import itemgetter
-from pathlib import Path
 from time import sleep
+from typing import TYPE_CHECKING
 
 from pytest import raises
 
+from tests.conftest import FLAKY
 from utilities.cacher import cache_to_disk
 from utilities.functions import identity
-from utilities.more_itertools import one
+from utilities.iterables import one
 from utilities.types import EnsureClassError
 
+if TYPE_CHECKING:
+    from pathlib import Path
+
 
 class TestCacheToDisk:
     def test_main(self, *, tmp_path: Path) -> None:
@@ -61,6 +65,7 @@ class TestCacheToDisk:
         assert func(0) == 0
         assert len(list(tmp_path.iterdir())) == 0
 
+    @FLAKY
     def test_max_duration(self, *, tmp_path: Path) -> None:
         max_duration = 0.1
         func = cache_to_disk(root=tmp_path, max_duration=max_duration)(identity)
@@ -95,11 +100,11 @@ class TestCacheToDisk:
         assert len(list(path.iterdir())) == 1
         pre = path.stat().st_mtime
         sleep(0.01)
-        assert func(0, rerun=True) == 0  # type: ignore
+        assert func(0, rerun=True) == 0  # pyright: ignore[reportCallIssue]
         post = path.stat().st_mtime
         assert pre < post
 
     def test_rerun_not_a_boolean(self, *, tmp_path: Path) -> None:
         func = cache_to_disk(root=tmp_path)(identity)
         with raises(EnsureClassError):
-            _ = func(0, rerun=None)  # type: ignore
+            _ = func(0, rerun=None)  # pyright: ignore[reportCallIssue]
