@@ -1,10 +1,12 @@
 from __future__ import annotations
 
-from typing import Any, cast
+import re
+from re import DOTALL
+from typing import TYPE_CHECKING, Any, cast
 
 import cvxpy
 import numpy as np
-from cvxpy import Expression, Maximize, Minimize, Problem, Variable
+from cvxpy import CLARABEL, Expression, Maximize, Minimize, Problem, Variable
 from numpy import array, isclose
 from numpy.testing import assert_equal
 from pandas import DataFrame, Series
@@ -12,10 +14,14 @@ from pandas.testing import assert_frame_equal, assert_series_equal
 from pytest import mark, param, raises
 
 from utilities.cvxpy import (
+    MaximumError,
+    MinimumError,
     MultiplyError,
     ScalarProductError,
     SolveInfeasibleError,
     SolveUnboundedError,
+    _check_series_and_dataframe,
+    _CheckSeriesAndDataFrameError,
     abs_,
     add,
     divide,
@@ -38,15 +44,16 @@ from utilities.cvxpy import (
     sum_axis0,
     sum_axis1,
 )
-from utilities.numpy import NDArrayF
-from utilities.pandas import SeriesF
+
+if TYPE_CHECKING:
+    from collections.abc import Callable
+
+    from utilities.numpy import NDArrayF
+    from utilities.pandas import SeriesF
 
 
 def _get_variable(
-    objective: type[Maximize] | type[Minimize],  # noqa: PYI055
-    /,
-    *,
-    shape: tuple[int, ...] | None = None,
+    objective: type[Maximize | Minimize], /, *, shape: tuple[int, ...] | None = None
 ) -> Variable:
     if shape is None:
         var = Variable()
@@ -58,7 +65,7 @@ def _get_variable(
     problem = Problem(
         objective(scalar), [cast(Any, var) >= -threshold, cast(Any, var) <= threshold]
     )
-    _ = problem.solve()
+    _ = problem.solve(solver=CLARABEL)
     return var
 
 
@@ -129,8 +136,8 @@ class TestAdd:
         self, *, x: float | NDArrayF | Expression, objective: type[Maximize | Minimize]
     ) -> None:
         var = _get_variable(objective)
-        assert isclose(add(x, var).value, add(x, var.value))  # type: ignore
-        assert isclose(add(var, x).value, add(var.value, x))  # type: ignore
+        assert isclose(add(x, var).value, add(x, var.value))  # pyright: ignore[reportArgumentType, reportCallIssue]
+        assert isclose(add(var, x).value, add(var.value, x))  # pyright: ignore[reportArgumentType, reportCallIssue]
 
     @mark.parametrize("objective1", [param(Maximize), param(Minimize)])
     @mark.parametrize("objective2", [param(Maximize), param(Minimize)])
@@ -145,6 +152,19 @@ class TestAdd:
         assert_equal(add(var1, var2).value, add(var1.value, var2.value))
 
 
+class TestCheckSeriesAndDataFrame:
+    def test_main(self) -> None:
+        x, y = Series([2.0]), DataFrame([3.0])
+        match = re.compile(
+            r"Function must not be between a Series and DataFrame; got .* and .*\.",
+            flags=DOTALL,
+        )
+        with raises(_CheckSeriesAndDataFrameError, match=match):
+            _ = _check_series_and_dataframe(cast(Any, x), cast(Any, y))
+        with raises(_CheckSeriesAndDataFrameError, match=match):
+            _ = _check_series_and_dataframe(cast(Any, y), cast(Any, x))
+
+
 class TestDivide:
     @mark.parametrize(
         ("x", "y", "expected"),
@@ -206,41 +226,113 @@ class TestMax:
         assert isclose(max_(var).value, max_(var.value))
 
 
-class TestMaximum:
-    @mark.parametrize(
-        ("x", "y", "expected"),
-        [
-            param(2.0, 3.0, 3.0),
-            param(2.0, array([3.0]), array([3.0])),
-            param(array([2.0]), 3.0, array([3.0])),
-            param(array([2.0]), array([3.0]), array([3.0])),
-        ],
-    )
-    def test_float_and_array(
-        self, *, x: float | NDArrayF, y: float | NDArrayF, expected: float | NDArrayF
-    ) -> None:
-        assert_equal(maximum(x, y), expected)
+class TestMaximumAndMinimum:
+    @mark.parametrize(("func", "expected"), [param(maximum, 3.0), param(minimum, 2.0)])
+    def test_two_floats(self, *, func: Callable[..., Any], expected: float) -> None:
+        assert isclose(func(2.0, 3.0), expected)
 
-    @mark.parametrize("x", [param(2.0), param(array([2.0]))])
-    @mark.parametrize("objective", [param(Maximize), param(Minimize)])
-    def test_one_expression(
-        self, *, x: float | NDArrayF | Expression, objective: type[Maximize | Minimize]
-    ) -> None:
-        var = _get_variable(objective)
-        assert_equal(maximum(x, var).value, maximum(x, var.value))
-        assert_equal(maximum(var, x).value, maximum(var.value, x))
+    @mark.parametrize(("func", "expected"), [param(maximum, 3.0), param(minimum, 2.0)])
+    def test_two_arrays(self, *, func: Callable[..., Any], expected: float) -> None:
+        assert_equal(func(array([2.0]), array([3.0])), array([expected]))
 
+    @mark.parametrize(("func", "expected"), [param(maximum, 3.0), param(minimum, 2.0)])
+    def test_two_series(self, *, func: Callable[..., Any], expected: float) -> None:
+        res = func(Series([2.0]), Series([3.0]))
+        exp_series = Series([expected])
+        assert_series_equal(res, exp_series)
+
+    @mark.parametrize(("func", "expected"), [param(maximum, 3.0), param(minimum, 2.0)])
+    def test_two_dataframes(self, *, func: Callable[..., Any], expected: float) -> None:
+        res = func(DataFrame([2.0]), DataFrame([3.0]))
+        exp_df = DataFrame([expected])
+        assert_frame_equal(res, exp_df)
+
+    @mark.parametrize("func", [param(maximum), param(minimum)])
     @mark.parametrize("objective1", [param(Maximize), param(Minimize)])
     @mark.parametrize("objective2", [param(Maximize), param(Minimize)])
     def test_two_expressions(
         self,
         *,
+        func: Callable[..., Any],
         objective1: type[Maximize | Minimize],
         objective2: type[Maximize | Minimize],
     ) -> None:
         var1 = _get_variable(objective1)
         var2 = _get_variable(objective2)
-        assert_equal(maximum(var1, var2).value, maximum(var1.value, var2.value))
+        assert isclose(func(var1, var2).value, func(var1.value, var2.value))
+
+    @mark.parametrize("func", [param(maximum), param(minimum)])
+    @mark.parametrize("objective", [param(Maximize), param(Minimize)])
+    @mark.parametrize("shape", [param(None), param((2, 2))])
+    def test_float_and_expr(
+        self,
+        *,
+        func: Callable[..., Any],
+        objective: type[Maximize | Minimize],
+        shape: tuple[int, ...] | None,
+    ) -> None:
+        x, y = 2.0, _get_variable(objective, shape=shape)
+        assert_equal(func(x, y).value, func(x, y.value))
+        assert_equal(func(y, x).value, func(y.value, x))
+
+    @mark.parametrize(("func", "expected"), [param(maximum, 3.0), param(minimum, 2.0)])
+    def test_array_and_series(
+        self, *, func: Callable[..., Any], expected: float
+    ) -> None:
+        x, y, exp_series = array([2.0]), Series([3.0]), Series([expected])
+        assert_series_equal(func(x, y), exp_series)
+        assert_series_equal(func(y, x), exp_series)
+
+    @mark.parametrize(("func", "expected"), [param(maximum, 3.0), param(minimum, 2.0)])
+    def test_array_and_dataframe(
+        self, *, func: Callable[..., Any], expected: float
+    ) -> None:
+        x, y, exp_df = array([2.0]), DataFrame([3.0]), DataFrame([expected])
+        assert_frame_equal(func(x, y), exp_df)
+        assert_frame_equal(func(y, x), exp_df)
+
+    @mark.parametrize("func", [param(maximum), param(minimum)])
+    @mark.parametrize("objective", [param(Maximize), param(Minimize)])
+    def test_array_and_expr(
+        self, *, func: Callable[..., Any], objective: type[Maximize | Minimize]
+    ) -> None:
+        x, y = array([2.0]), _get_variable(objective)
+        assert isclose(func(x, y).value, func(x, y.value))
+        assert isclose(func(y, x).value, func(y.value, x))
+
+    @mark.parametrize(
+        ("func", "error"), [param(maximum, MaximumError), param(minimum, MinimumError)]
+    )
+    def test_series_and_dataframe(
+        self, func: Callable[..., Any], error: type[Exception]
+    ) -> None:
+        x, y = Series([2.0]), DataFrame([3.0])
+        match = re.compile(
+            r".* must not be between a Series and DataFrame; got .* and .*\.",
+            flags=DOTALL,
+        )
+        with raises(error, match=match):
+            _ = func(cast(Any, x), cast(Any, y))
+        with raises(error, match=match):
+            _ = func(cast(Any, y), cast(Any, x))
+
+    @mark.parametrize("func", [param(maximum), param(minimum)])
+    @mark.parametrize("objective", [param(Maximize), param(Minimize)])
+    def test_series_and_expr(
+        self, *, func: Callable[..., Any], objective: type[Maximize | Minimize]
+    ) -> None:
+        x, y = Series([2.0]), _get_variable(objective)
+        assert isclose(func(x, y).value, func(x, y.value))
+        assert isclose(func(y, x).value, func(y.value, x))
+
+    @mark.parametrize("func", [param(maximum), param(minimum)])
+    @mark.parametrize("objective", [param(Maximize), param(Minimize)])
+    def test_dataframe_and_expr(
+        self, *, func: Callable[..., Any], objective: type[Maximize | Minimize]
+    ) -> None:
+        x, y = DataFrame([2.0]), _get_variable(objective)
+        assert isclose(func(x, y).value, func(x, y.value))
+        assert isclose(func(y, x).value, func(y.value, x))
 
 
 class TestMin:
@@ -267,43 +359,6 @@ class TestMin:
         assert isclose(min_(var).value, min_(var.value))
 
 
-class TestMinimum:
-    @mark.parametrize(
-        ("x", "y", "expected"),
-        [
-            param(2.0, 3.0, 2.0),
-            param(2.0, array([3.0]), array([2.0])),
-            param(array([2.0]), 3.0, array([2.0])),
-            param(array([2.0]), array([3.0]), array([2.0])),
-        ],
-    )
-    def test_float_and_array(
-        self, *, x: float | NDArrayF, y: float | NDArrayF, expected: float | NDArrayF
-    ) -> None:
-        assert_equal(minimum(x, y), expected)
-
-    @mark.parametrize("x", [param(2.0), param(array([2.0]))])
-    @mark.parametrize("objective", [param(Maximize), param(Minimize)])
-    def test_one_expression(
-        self, *, x: float | NDArrayF | Expression, objective: type[Maximize | Minimize]
-    ) -> None:
-        var = _get_variable(objective)
-        assert_equal(minimum(x, var).value, minimum(x, var.value))
-        assert_equal(minimum(var, x).value, minimum(var.value, x))
-
-    @mark.parametrize("objective1", [param(Maximize), param(Minimize)])
-    @mark.parametrize("objective2", [param(Maximize), param(Minimize)])
-    def test_two_expressions(
-        self,
-        *,
-        objective1: type[Maximize | Minimize],
-        objective2: type[Maximize | Minimize],
-    ) -> None:
-        var1 = _get_variable(objective1)
-        var2 = _get_variable(objective2)
-        assert_equal(minimum(var1, var2).value, minimum(var1.value, var2.value))
-
-
 class TestMultiply:
     def test_two_floats(self) -> None:
         assert isclose(multiply(2.0, 3.0), 6.0)
@@ -375,9 +430,13 @@ class TestMultiply:
 
     def test_series_and_dataframe(self) -> None:
         x, y = Series([2.0]), DataFrame([3.0])
-        with raises(MultiplyError):
+        match = re.compile(
+            r"Multiply must not be between a Series and DataFrame; got .* and .*\.",
+            flags=DOTALL,
+        )
+        with raises(MultiplyError, match=match):
             _ = multiply(cast(Any, x), cast(Any, y))
-        with raises(MultiplyError):
+        with raises(MultiplyError, match=match):
             _ = multiply(cast(Any, y), cast(Any, x))
 
     @mark.parametrize("objective", [param(Maximize), param(Minimize)])
@@ -433,11 +492,7 @@ class TestNegate:
         assert_frame_equal(negate(x), expected)
 
     @mark.parametrize("objective", [param(Maximize), param(Minimize)])
-    def test_expression(
-        self,
-        *,
-        objective: type[Maximize] | type[Minimize],  # noqa: PYI055
-    ) -> None:
+    def test_expression(self, *, objective: type[Maximize | Minimize]) -> None:
         var = _get_variable(objective)
         assert_equal(negate(var).value, negate(var.value))
 
@@ -459,12 +514,30 @@ class TestNegative:
     ) -> None:
         assert_equal(negative(x), expected)
 
+    @mark.parametrize(
+        ("x", "expected"),
+        [
+            param(Series([0.0]), Series([0.0])),
+            param(Series([1.0]), Series([0.0])),
+            param(Series([-1.0]), Series([1.0])),
+        ],
+    )
+    def test_series(self, *, x: SeriesF, expected: SeriesF) -> None:
+        assert_series_equal(negative(x), expected)
+
+    @mark.parametrize(
+        ("x", "expected"),
+        [
+            param(DataFrame([0.0]), DataFrame([0.0])),
+            param(DataFrame([1.0]), DataFrame([0.0])),
+            param(DataFrame([-1.0]), DataFrame([1.0])),
+        ],
+    )
+    def test_dataframe(self, *, x: DataFrame, expected: DataFrame) -> None:
+        assert_frame_equal(negative(x), expected)
+
     @mark.parametrize("objective", [param(Maximize), param(Minimize)])
-    def test_expression(
-        self,
-        *,
-        objective: type[Maximize] | type[Minimize],  # noqa: PYI055
-    ) -> None:
+    def test_expression(self, *, objective: type[Maximize | Minimize]) -> None:
         var = _get_variable(objective)
         assert isclose(negative(var).value, negative(var.value))
 
@@ -500,6 +573,28 @@ class TestPositive:
     ) -> None:
         assert_equal(positive(x), expected)
 
+    @mark.parametrize(
+        ("x", "expected"),
+        [
+            param(Series([0.0]), Series([0.0])),
+            param(Series([1.0]), Series([1.0])),
+            param(Series([-1.0]), Series([0.0])),
+        ],
+    )
+    def test_series(self, *, x: SeriesF, expected: SeriesF) -> None:
+        assert_series_equal(positive(x), expected)
+
+    @mark.parametrize(
+        ("x", "expected"),
+        [
+            param(DataFrame([0.0]), DataFrame([0.0])),
+            param(DataFrame([1.0]), DataFrame([1.0])),
+            param(DataFrame([-1.0]), DataFrame([0.0])),
+        ],
+    )
+    def test_dataframe(self, *, x: DataFrame, expected: DataFrame) -> None:
+        assert_frame_equal(positive(x), expected)
+
     @mark.parametrize("objective", [param(Maximize), param(Minimize)])
     def test_expression(self, *, objective: type[Maximize | Minimize]) -> None:
         var = _get_variable(objective)
@@ -569,9 +664,13 @@ class TestScalarProduct:
         if (isinstance(x, Series) and isinstance(y, DataFrame)) or (
             isinstance(x, DataFrame) and isinstance(y, Series)
         ):
-            with raises(ScalarProductError):
+            match = re.compile(
+                r".* must not be between a Series and DataFrame; got .* and .*\.",
+                flags=DOTALL,
+            )
+            with raises(ScalarProductError, match=match):
                 _ = scalar_product(cast(Any, x), cast(Any, y))
-            with raises(ScalarProductError):
+            with raises(ScalarProductError, match=match):
                 _ = scalar_product(cast(Any, y), cast(Any, x))
         else:
             assert isclose(scalar_product(cast(Any, y), cast(Any, x)), 6.0)
@@ -626,7 +725,7 @@ class TestSolve:
     def test_main(self) -> None:
         var = Variable()
         problem = Problem(Minimize(sum_(abs_(var))), [])
-        _ = solve(problem)
+        _ = solve(problem, solver=CLARABEL)
 
     def test_infeasible_problem(self) -> None:
         var = Variable()
@@ -636,13 +735,13 @@ class TestSolve:
             [cast(Any, var) >= threshold, cast(Any, var) <= -threshold],
         )
         with raises(SolveInfeasibleError):
-            _ = solve(problem)
+            _ = solve(problem, solver=CLARABEL)
 
     def test_unbounded_problem(self) -> None:
         var = Variable()
         problem = Problem(Maximize(sum_(var)), [])
         with raises(SolveUnboundedError):
-            _ = solve(problem)
+            _ = solve(problem, solver=CLARABEL)
 
 
 class TestSqrt:
