@@ -12,7 +12,6 @@ from utilities.git import (
     get_repo_name,
     get_repo_root,
     get_repo_root_or_cwd_sub_path,
-    valid_path_repo,
 )
 from utilities.hypothesis import (
     git_repos,
@@ -20,7 +19,6 @@ from utilities.hypothesis import (
     temp_paths,
     text_ascii,
 )
-from utilities.pathvalidate import valid_path
 
 
 class TestGetBranchName:
@@ -57,16 +55,16 @@ class TestGetRepoRootOrCwdSubPath:
     @settings_with_reduced_examples()
     def test_exists(self, *, root: Path) -> None:
         def get_file(root: Path, /) -> Path:
-            return valid_path(root, "file.txt")
+            return Path(root, "file.txt")
 
         result = get_repo_root_or_cwd_sub_path(get_file, cwd=root)
-        expected = valid_path(root, "file.txt").resolve()
+        expected = Path(root, "file.txt").resolve()
         assert result == expected
 
     @given(root=temp_paths())
     def test_does_not_exist(self, *, root: Path) -> None:
         def get_file(root: Path, /) -> Path:
-            return valid_path(root, "file.txt")
+            return Path(root, "file.txt")
 
         result = get_repo_root_or_cwd_sub_path(get_file, cwd=root)
         assert result is None
@@ -74,15 +72,15 @@ class TestGetRepoRootOrCwdSubPath:
     @given(root=temp_paths())
     def test_missing(self, *, root: Path) -> None:
         def get_file_1(root: Path, /) -> Path:
-            return valid_path(root, "file_1.txt")
+            return Path(root, "file_1.txt")
 
         def get_file_2(root: Path, /) -> Path:
-            return valid_path(root, "file_2.txt")
+            return Path(root, "file_2.txt")
 
         result = get_repo_root_or_cwd_sub_path(
             get_file_1, cwd=root, if_missing=get_file_2
         )
-        expected = valid_path(root, "file_2.txt")
+        expected = Path(root, "file_2.txt")
         assert result == expected
 
 
@@ -90,6 +88,6 @@ class TestValidRepoPath:
     @given(root=git_repos(), file_name=text_ascii())
     @settings_with_reduced_examples()
     def test_main(self, *, root: Path, file_name: str) -> None:
-        result = valid_path_repo(file_name, cwd=root)
-        expected = valid_path(root.resolve(), file_name)
+        result = get_repo_root(cwd=root).joinpath(file_name)
+        expected = Path(root.resolve(), file_name)
         assert result == expected
