@@ -1,56 +1,16 @@
 from __future__ import annotations
 
-from contextlib import suppress
 from math import inf, nan
-from typing import Any
+from re import escape
+from typing import ClassVar
 
-from beartype.door import die_if_unbearable
-from beartype.roar import BeartypeDoorHintViolation
 from hypothesis import given
-from hypothesis.strategies import floats, integers
-from pytest import mark, param, raises
+from hypothesis.strategies import integers
+from pytest import approx, mark, param, raises
 
-from utilities.hypothesis import settings_with_reduced_examples
 from utilities.math import (
     CheckIntegerError,
-    FloatFin,
-    FloatFinInt,
-    FloatFinIntNan,
-    FloatFinNan,
-    FloatFinNeg,
-    FloatFinNegNan,
-    FloatFinNonNeg,
-    FloatFinNonNegNan,
-    FloatFinNonPos,
-    FloatFinNonPosNan,
-    FloatFinNonZr,
-    FloatFinNonZrNan,
-    FloatFinPos,
-    FloatFinPosNan,
-    FloatInt,
-    FloatIntNan,
-    FloatNeg,
-    FloatNegNan,
-    FloatNonNeg,
-    FloatNonNegNan,
-    FloatNonPos,
-    FloatNonPosNan,
-    FloatNonZr,
-    FloatNonZrNan,
-    FloatPos,
-    FloatPosNan,
-    FloatZr,
-    FloatZrFinNonMic,
-    FloatZrFinNonMicNan,
-    FloatZrNan,
-    FloatZrNonMic,
-    FloatZrNonMicNan,
-    IntNeg,
-    IntNonNeg,
-    IntNonPos,
-    IntNonZr,
-    IntPos,
-    IntZr,
+    NumberOfDecimalsError,
     check_integer,
     is_at_least,
     is_at_least_or_nan,
@@ -96,61 +56,12 @@ from utilities.math import (
     is_zero_or_nan,
     is_zero_or_non_micro,
     is_zero_or_non_micro_or_nan,
+    number_of_decimals,
+    order_of_magnitude,
 )
 
 
-class TestAnnotations:
-    @given(x=integers() | floats(allow_infinity=True, allow_nan=True))
-    @mark.parametrize(
-        "hint",
-        [
-            param(IntNeg),
-            param(IntNonNeg),
-            param(IntNonPos),
-            param(IntNonZr),
-            param(IntPos),
-            param(IntZr),
-            param(FloatFin),
-            param(FloatFinInt),
-            param(FloatFinIntNan),
-            param(FloatFinNeg),
-            param(FloatFinNegNan),
-            param(FloatFinNonNeg),
-            param(FloatFinNonNegNan),
-            param(FloatFinNonPos),
-            param(FloatFinNonPosNan),
-            param(FloatFinNonZr),
-            param(FloatFinNonZrNan),
-            param(FloatFinPos),
-            param(FloatFinPosNan),
-            param(FloatFinNan),
-            param(FloatInt),
-            param(FloatIntNan),
-            param(FloatNeg),
-            param(FloatNegNan),
-            param(FloatNonNeg),
-            param(FloatNonNegNan),
-            param(FloatNonPos),
-            param(FloatNonPosNan),
-            param(FloatNonZr),
-            param(FloatNonZrNan),
-            param(FloatPos),
-            param(FloatPosNan),
-            param(FloatZr),
-            param(FloatZrFinNonMic),
-            param(FloatZrFinNonMicNan),
-            param(FloatZrNan),
-            param(FloatZrNonMic),
-            param(FloatZrNonMicNan),
-        ],
-    )
-    @settings_with_reduced_examples()
-    def test_main(self, *, x: float, hint: Any) -> None:
-        with suppress(BeartypeDoorHintViolation):
-            die_if_unbearable(x, hint)
-
-
-class TestCheckinteger:
+class TestCheckInteger:
     def test_equal_pass(self) -> None:
         check_integer(0, equal=0)
 
@@ -759,3 +670,63 @@ class TestIsZeroOrNonMicro:
     def test_main(self, *, x: float, expected: bool) -> None:
         assert is_zero_or_non_micro(x, abs_tol=1e-8) is expected
         assert is_zero_or_non_micro_or_nan(x, abs_tol=1e-8) is expected
+
+
+class TestOrderOfMagnitude:
+    @mark.parametrize(
+        ("x", "exp_float", "exp_int"),
+        [
+            param(0.25, -0.60206, -1),
+            param(0.5, -0.30103, 0),
+            param(0.75, -0.1249387, 0),
+            param(1.0, 0.0, 0),
+            param(5.0, 0.69897, 1),
+            param(10.0, 1.0, 1),
+            param(50.0, 1.69897, 2),
+            param(100.0, 2.0, 2),
+        ],
+    )
+    @mark.parametrize("sign", [param(1.0), param(-1.0)])
+    def test_main(
+        self, *, sign: float, x: float, exp_float: float, exp_int: int
+    ) -> None:
+        x_use = sign * x
+        res_float = order_of_magnitude(x_use)
+        assert res_float == approx(exp_float)
+        res_int = order_of_magnitude(x_use, round_=True)
+        assert res_int == exp_int
+
+
+class TestNumberOfDecimals:
+    max_int: ClassVar[int] = int(1e6)
+
+    @given(integer=integers(-max_int, max_int))
+    @mark.parametrize(
+        ("frac", "expected"),
+        [
+            param(0.0, 0),
+            param(0.1, 1),
+            param(0.12, 2),
+            param(0.123, 3),
+            param(0.1234, 4),
+            param(0.12345, 5),
+            param(0.123456, 6),
+            param(0.1234567, 7),
+            param(0.12345678, 8),
+            param(0.123456789, 9),
+        ],
+    )
+    def test_main(self, *, integer: int, frac: float, expected: int) -> None:
+        x = integer + frac
+        result = number_of_decimals(x)
+        assert result == expected
+
+    def test_equal_fail(self) -> None:
+        x = 1.401298464324817e-45
+        with raises(
+            NumberOfDecimalsError,
+            match=escape(
+                "Could not determine number of decimals of 1.401298464324817e-45 (up to 20)"
+            ),
+        ):
+            _ = number_of_decimals(x)
