@@ -1,13 +1,12 @@
 from __future__ import annotations
 
 import datetime as dt
-from collections.abc import Callable
-from contextlib import suppress
-from typing import Any, cast
+import re
+from re import DOTALL
+from typing import TYPE_CHECKING, Any, Literal, cast
 
-from beartype.door import die_if_unbearable
-from beartype.roar import BeartypeDoorHintViolation
 from hypothesis import assume, given
+from hypothesis.strategies import none
 from numpy import array, nan
 from numpy.testing import assert_equal
 from pandas import (
@@ -21,115 +20,109 @@ from pandas import (
     concat,
     to_datetime,
 )
-from pandas.testing import assert_index_equal, assert_series_equal
+from pandas.testing import assert_frame_equal, assert_index_equal, assert_series_equal
 from pytest import mark, param, raises
 
-from utilities.datetime import TODAY_UTC, UTC
-from utilities.hypothesis import int_indexes, text_ascii, timestamps
-from utilities.numpy import dt64ns
+from utilities.datetime import TODAY_UTC
+from utilities.hypothesis import text_ascii, timestamps
+from utilities.numpy import datetime64ns
 from utilities.pandas import (
     TIMESTAMP_MAX_AS_DATE,
     TIMESTAMP_MAX_AS_DATETIME,
     TIMESTAMP_MIN_AS_DATE,
     TIMESTAMP_MIN_AS_DATETIME,
+    AssignBeforeOrAfterError,
+    AssignBetweenIndexError,
+    AssignBetweenIndicesError,
     CheckIndexError,
     CheckPandasDataFrameError,
     CheckRangeIndexError,
     EmptyPandasConcatError,
-    IndexA,
-    IndexB,
-    IndexBn,
-    IndexC,
-    IndexD,
-    IndexDhk,
-    IndexDutc,
-    IndexF,
-    IndexI,
-    IndexI64,
-    IndexS,
-    IndexSt,
     Int64,
+    ReindexToSetError,
+    ReindexToSubSetError,
+    ReindexToSuperSetError,
     SeriesA,
-    SeriesB,
-    SeriesBn,
-    SeriesC,
-    SeriesD,
-    SeriesDhk,
-    SeriesDutc,
-    SeriesF,
-    SeriesI,
-    SeriesI64,
     SeriesMinMaxError,
-    SeriesS,
-    SeriesSt,
     TimestampToDateTimeError,
-    astype,
+    UnionIndexesError,
+    assign_after,
+    assign_before,
+    assign_between,
     boolean,
     check_index,
     check_pandas_dataframe,
     check_range_index,
     redirect_empty_pandas_concat,
-    rename_index,
+    reindex_to_set,
+    reindex_to_subset,
+    reindex_to_superset,
     series_max,
     series_min,
-    sort_index,
     string,
     timestamp_to_date,
     timestamp_to_datetime,
     to_numpy,
+    union_indexes,
 )
+from utilities.zoneinfo import UTC
+
+if TYPE_CHECKING:
+    from collections.abc import Callable
 
 
-class TestAsType:
+class TestAssignBeforeOrAfter:
+    def test_after(self) -> None:
+        df = DataFrame([[0, 1, 2]], columns=Index(["a", "b", "c"]))
+        result = assign_after(df, "b", Series(9, name="z"))
+        expected = DataFrame([[0, 1, 9, 2]], columns=Index(["a", "b", "z", "c"]))
+        assert_frame_equal(result, expected)
+
+    def test_before(self) -> None:
+        df = DataFrame([[0, 1, 2]], columns=Index(["a", "b", "c"]))
+        result = assign_before(df, "b", Series(9, name="z"))
+        expected = DataFrame([[0, 9, 1, 2]], columns=Index(["a", "z", "b", "c"]))
+        assert_frame_equal(result, expected)
+
+    @mark.parametrize("mode", [param("before"), param("after")])
+    def test_error(self, *, mode: Literal["before", "after"]) -> None:
+        df = DataFrame([[0, 1, 2]], columns=Index(["a", "b", "c"]))
+        match mode:
+            case "before":
+                func = assign_before
+            case "after":
+                func = assign_after
+        with raises(
+            AssignBeforeOrAfterError,
+            match="DataFrame must contain exactly one column named 'd'",
+        ):
+            _ = func(df, "d", Series(9, name="z"))
+
+
+class TestAssignBetween:
     def test_main(self) -> None:
-        df = DataFrame(0, index=RangeIndex(1), columns=["value"], dtype=int)
-        check_pandas_dataframe(df, dtypes={"value": int})
-        result = astype(df, float)
-        check_pandas_dataframe(result, dtypes={"value": float})
+        df = DataFrame([[0, 1, 2, 3]], columns=Index(["a", "b", "c", "d"]))
+        result = assign_between(df, "b", "c", Series(9, name="z"))
+        expected = DataFrame(
+            [[0, 1, 9, 2, 3]], columns=Index(["a", "b", "z", "c", "d"])
+        )
+        assert_frame_equal(result, expected)
 
+    def test_error_index(self) -> None:
+        df = DataFrame([[0, 1, 2]], columns=Index(["a", "b", "c"]))
+        with raises(
+            AssignBetweenIndexError,
+            match="DataFrame must contain exactly one column named 'd'",
+        ):
+            _ = assign_between(df, "d", "e", Series(9, name="z"))
 
-class TestBeartype:
-    @mark.parametrize(
-        "hint",
-        [
-            param(IndexA),
-            param(IndexB),
-            param(IndexBn),
-            param(IndexC),
-            param(IndexD),
-            param(IndexDhk),
-            param(IndexDutc),
-            param(IndexF),
-            param(IndexI),
-            param(IndexI64),
-            param(IndexS),
-            param(IndexSt),
-        ],
-    )
-    def test_index(self, *, hint: Any) -> None:
-        with suppress(BeartypeDoorHintViolation):
-            die_if_unbearable(Index([]), hint)
-
-    @mark.parametrize(
-        "hint",
-        [
-            param(SeriesA),
-            param(SeriesB),
-            param(SeriesBn),
-            param(SeriesC),
-            param(SeriesD),
-            param(SeriesDhk),
-            param(SeriesDutc),
-            param(SeriesF),
-            param(SeriesI),
-            param(SeriesI64),
-            param(SeriesS),
-            param(SeriesSt),
-        ],
-    )
-    def test_series(self, *, hint: Any) -> None:
-        with suppress(BeartypeDoorHintViolation):
-            die_if_unbearable(Series([]), hint)
+    def test_error_indices(self) -> None:
+        df = DataFrame([[0, 1, 2]], columns=Index(["a", "b", "c"]))
+        with raises(
+            AssignBetweenIndicesError,
+            match="DataFrame must specify consecutive indices; got 0 and 2",
+        ):
+            _ = assign_between(df, "a", "c", Series(9, name="z"))
 
 
 class TestCheckIndex:
@@ -140,42 +133,50 @@ class TestCheckIndex:
         check_index(RangeIndex(1), length=1)
 
     def test_length_error(self) -> None:
-        with raises(CheckIndexError):
+        with raises(
+            CheckIndexError, match=r"Index .* must satisfy the length requirements\."
+        ):
             check_index(RangeIndex(1), length=2)
 
     def test_min_length_pass(self) -> None:
         check_index(RangeIndex(2), min_length=1)
 
     def test_min_length_error(self) -> None:
-        with raises(CheckIndexError):
+        with raises(
+            CheckIndexError, match=r"Index .* must satisfy the length requirements\."
+        ):
             check_index(RangeIndex(0), min_length=1)
 
     def test_max_length_pass(self) -> None:
         check_index(RangeIndex(0), max_length=1)
 
     def test_max_length_error(self) -> None:
-        with raises(CheckIndexError):
+        with raises(
+            CheckIndexError, match=r"Index .* must satisfy the length requirements\."
+        ):
             check_index(RangeIndex(2), max_length=1)
 
     def test_name_pass(self) -> None:
         check_index(RangeIndex(0), name=None)
 
     def test_name_error(self) -> None:
-        with raises(CheckIndexError):
+        with raises(
+            CheckIndexError, match=r"Index .* must satisfy the name requirement\."
+        ):
             check_index(RangeIndex(0), name="name")
 
     def test_sorted_pass(self) -> None:
         check_index(Index(["A", "B"]), sorted=True)
 
     def test_sorted_error(self) -> None:
-        with raises(CheckIndexError):
+        with raises(CheckIndexError, match=r"Index .* must be sorted\."):
             check_index(Index(["B", "A"]), sorted=True)
 
     def test_unique_pass(self) -> None:
         check_index(Index(["A", "B"]), unique=True)
 
     def test_unique_error(self) -> None:
-        with raises(CheckIndexError):
+        with raises(CheckIndexError, match=r"Index .* must be unique\."):
             check_index(Index(["A", "A"]), unique=True)
 
 
@@ -183,6 +184,101 @@ class TestCheckPandasDataFrame:
     def test_main(self) -> None:
         check_pandas_dataframe(DataFrame())
 
+    def test_columns_pass(self) -> None:
+        df = DataFrame(0.0, index=RangeIndex(0), columns=Index([]))
+        check_pandas_dataframe(df, columns=[])
+
+    def test_columns_error(self) -> None:
+        df = DataFrame(0.0, index=RangeIndex(0), columns=Index(["value"]))
+        with raises(
+            CheckPandasDataFrameError,
+            match=re.compile(
+                r"DataFrame must have columns .*; got .*\n\n.*\.", flags=DOTALL
+            ),
+        ):
+            check_pandas_dataframe(df, columns=["other"])
+
+    def test_dtypes_pass(self) -> None:
+        df = DataFrame(0.0, index=RangeIndex(0), columns=Index([]))
+        check_pandas_dataframe(df, dtypes={})
+
+    def test_dtypes_error_set_of_columns(self) -> None:
+        df = DataFrame(0.0, index=RangeIndex(0), columns=Index([]))
+        with raises(
+            CheckPandasDataFrameError,
+            match=re.compile(
+                r"DataFrame must have dtypes .*; got .*\n\n.*\.", flags=DOTALL
+            ),
+        ):
+            check_pandas_dataframe(df, dtypes={"value": int})
+
+    def test_dtypes_error_order_of_columns(self) -> None:
+        df = DataFrame(0.0, index=RangeIndex(0), columns=Index(["a", "b"]))
+        with raises(
+            CheckPandasDataFrameError,
+            match=re.compile(
+                r"DataFrame must have dtypes .*; got .*\n\n.*\.", flags=DOTALL
+            ),
+        ):
+            check_pandas_dataframe(df, dtypes={"b": float, "a": float})
+
+    def test_length_pass(self) -> None:
+        df = DataFrame(0.0, index=RangeIndex(1), columns=Index(["value"]))
+        check_pandas_dataframe(df, length=1)
+
+    def test_length_error(self) -> None:
+        df = DataFrame(0.0, index=RangeIndex(1), columns=Index(["value"]))
+        with raises(
+            CheckPandasDataFrameError,
+            match=re.compile(
+                r"DataFrame must satisfy the length requirements; got .*\n\n.*\.",
+                flags=DOTALL,
+            ),
+        ):
+            check_pandas_dataframe(df, length=2)
+
+    def test_min_length_pass(self) -> None:
+        df = DataFrame(0.0, index=RangeIndex(2), columns=Index(["value"]))
+        check_pandas_dataframe(df, min_length=1)
+
+    def test_min_length_error(self) -> None:
+        df = DataFrame(0.0, index=RangeIndex(0), columns=Index(["value"]))
+        with raises(
+            CheckPandasDataFrameError,
+            match=re.compile(
+                r"DataFrame must satisfy the length requirements; got .*\n\n.*\.",
+                flags=DOTALL,
+            ),
+        ):
+            check_pandas_dataframe(df, min_length=1)
+
+    def test_max_length_pass(self) -> None:
+        df = DataFrame(0.0, index=RangeIndex(0), columns=Index(["value"]))
+        check_pandas_dataframe(df, max_length=1)
+
+    def test_max_length_error(self) -> None:
+        df = DataFrame(0.0, index=RangeIndex(2), columns=Index(["value"]))
+        with raises(
+            CheckPandasDataFrameError,
+            match=re.compile(
+                r"DataFrame must satisfy the length requirements; got .*\n\n.*\.",
+                flags=DOTALL,
+            ),
+        ):
+            check_pandas_dataframe(df, max_length=1)
+
+    def test_sorted_pass(self) -> None:
+        df = DataFrame([[0.0], [1.0]], index=RangeIndex(2), columns=Index(["value"]))
+        check_pandas_dataframe(df, sorted="value")
+
+    def test_sorted_error(self) -> None:
+        df = DataFrame([[1.0], [0.0]], index=RangeIndex(2), columns=Index(["value"]))
+        with raises(
+            CheckPandasDataFrameError,
+            match=re.compile(r"DataFrame must be sorted on .*\n\n.*\.", flags=DOTALL),
+        ):
+            check_pandas_dataframe(df, sorted="value")
+
     def test_standard_pass(self) -> None:
         check_pandas_dataframe(DataFrame(index=RangeIndex(0)), standard=True)
 
@@ -199,6 +295,20 @@ class TestCheckPandasDataFrame:
                     0.0, index=RangeIndex(1, name="name"), columns=Index(["value"])
                 )
             ),
+        ],
+    )
+    def test_standard_errors_index(self, *, df: DataFrame) -> None:
+        with raises(
+            CheckPandasDataFrameError,
+            match=re.compile(
+                r"DataFrame must have a standard index; got .*\n\n.*\.", flags=DOTALL
+            ),
+        ):
+            check_pandas_dataframe(df, standard=True)
+
+    @mark.parametrize(
+        "df",
+        [
             param(
                 DataFrame(
                     0.0, index=RangeIndex(1), columns=Index(["value"], name="name")
@@ -210,72 +320,40 @@ class TestCheckPandasDataFrame:
         ],
     )
     def test_standard_errors(self, *, df: DataFrame) -> None:
-        with raises(CheckPandasDataFrameError):
+        with raises(
+            CheckPandasDataFrameError,
+            match=re.compile(
+                r"DataFrame must have standard columns; got .*\n\n.*\.", flags=DOTALL
+            ),
+        ):
             check_pandas_dataframe(df, standard=True)
 
-    def test_columns_pass(self) -> None:
-        df = DataFrame(0.0, index=RangeIndex(1), columns=["value"])
-        check_pandas_dataframe(df, columns=["value"])
-
-    def test_columns_error(self) -> None:
-        df = DataFrame(0.0, index=RangeIndex(1), columns=["value"])
-        with raises(CheckPandasDataFrameError):
-            check_pandas_dataframe(df, columns=["other"])
-
-    def test_dtypes_pass(self) -> None:
-        df = DataFrame(0.0, index=RangeIndex(1), columns=["value"])
-        check_pandas_dataframe(df, dtypes={"value": float})
-
-    def test_dtypes_error(self) -> None:
-        df = DataFrame(0.0, index=RangeIndex(1), columns=["value"])
-        with raises(CheckPandasDataFrameError):
-            check_pandas_dataframe(df, dtypes={"value": int})
-
-    def test_length_pass(self) -> None:
-        df = DataFrame(0.0, index=RangeIndex(1), columns=["value"])
-        check_pandas_dataframe(df, length=1)
-
-    def test_length_error(self) -> None:
-        df = DataFrame(0.0, index=RangeIndex(1), columns=["value"])
-        with raises(CheckPandasDataFrameError):
-            check_pandas_dataframe(df, length=2)
-
-    def test_min_length_pass(self) -> None:
-        df = DataFrame(0.0, index=RangeIndex(2), columns=["value"])
-        check_pandas_dataframe(df, min_length=1)
-
-    def test_min_length_error(self) -> None:
-        df = DataFrame(0.0, index=RangeIndex(0), columns=["value"])
-        with raises(CheckPandasDataFrameError):
-            check_pandas_dataframe(df, min_length=1)
-
-    def test_max_length_pass(self) -> None:
-        df = DataFrame(0.0, index=RangeIndex(0), columns=["value"])
-        check_pandas_dataframe(df, max_length=1)
-
-    def test_max_length_error(self) -> None:
-        df = DataFrame(0.0, index=RangeIndex(2), columns=["value"])
-        with raises(CheckPandasDataFrameError):
-            check_pandas_dataframe(df, max_length=1)
-
-    def test_sorted_pass(self) -> None:
-        df = DataFrame([[0.0], [1.0]], index=RangeIndex(2), columns=["value"])
-        check_pandas_dataframe(df, sorted="value")
-
-    def test_sorted_error(self) -> None:
-        df = DataFrame([[1.0], [0.0]], index=RangeIndex(2), columns=["value"])
-        with raises(CheckPandasDataFrameError):
-            check_pandas_dataframe(df, sorted="value")
-
     def test_unique_pass(self) -> None:
-        df = DataFrame([[0.0], [1.0]], index=RangeIndex(2), columns=["value"])
+        df = DataFrame([[0.0], [1.0]], index=RangeIndex(2), columns=Index(["value"]))
         check_pandas_dataframe(df, unique="value")
 
     def test_unique_error(self) -> None:
-        df = DataFrame(0.0, index=RangeIndex(2), columns=["value"])
-        with raises(CheckPandasDataFrameError):
+        df = DataFrame(0.0, index=RangeIndex(2), columns=Index(["value"]))
+        with raises(
+            CheckPandasDataFrameError,
+            match=re.compile(r"DataFrame must be unique on .*\n\n.*\.", flags=DOTALL),
+        ):
             check_pandas_dataframe(df, unique="value")
 
+    def test_width_pass(self) -> None:
+        df = DataFrame()
+        check_pandas_dataframe(df, width=0)
+
+    def test_width_error(self) -> None:
+        df = DataFrame()
+        with raises(
+            CheckPandasDataFrameError,
+            match=re.compile(
+                r"DataFrame must have width .*; got .*\n\n.*\.", flags=DOTALL
+            ),
+        ):
+            check_pandas_dataframe(df, width=1)
+
 
 class TestCheckRangeIndex:
     def test_main(self) -> None:
@@ -337,19 +415,62 @@ class TestDTypes:
         assert isinstance(Series([], dtype=dtype), Series)
 
 
+class TestReindexToSet:
+    @given(name=text_ascii() | none())
+    def test_main(self, *, name: str | None) -> None:
+        index = Index([1, 2, 3], name=name)
+        target = [3, 2, 1]
+        result = reindex_to_set(index, target)
+        expected = Index([3, 2, 1], name=name)
+        assert_index_equal(result, expected)
+
+    def test_error(self) -> None:
+        index = Index([1, 2, 3])
+        target = [2, 3, 4]
+        with raises(
+            ReindexToSetError, match=r"Index .* and .* must be equal as sets\."
+        ):
+            _ = reindex_to_set(index, target)
+
+
+class TestReindexToSubSet:
+    @given(name=text_ascii() | none())
+    def test_main(self, *, name: str | None) -> None:
+        index = Index([1, 2, 3], name=name)
+        target = [1]
+        result = reindex_to_subset(index, target)
+        expected = Index([1], name=name)
+        assert_index_equal(result, expected)
+
+    def test_error(self) -> None:
+        index = Index([1])
+        target = [1, 2, 3]
+        with raises(ReindexToSubSetError, match=r"Index .* must be a superset of .*\."):
+            _ = reindex_to_subset(index, target)
+
+
+class TestReindexToSuperSet:
+    @given(name=text_ascii() | none())
+    def test_main(self, *, name: str | None) -> None:
+        index = Index([1], name=name)
+        target = [1, 2, 3]
+        result = reindex_to_superset(index, target)
+        expected = Index([1, 2, 3], name=name)
+        assert_index_equal(result, expected)
+
+    def test_error(self) -> None:
+        index = Index([1, 2, 3])
+        target = [1]
+        with raises(ReindexToSuperSetError, match=r"Index .* must be a subset of .*\."):
+            _ = reindex_to_superset(index, target)
+
+
 class TestRedirectEmptyPandasConcat:
     def test_main(self) -> None:
         with raises(EmptyPandasConcatError), redirect_empty_pandas_concat():
             _ = concat([])
 
 
-class TestRenameIndex:
-    @given(index=int_indexes(), name=text_ascii())
-    def test_main(self, *, index: IndexI, name: str) -> None:
-        renamed = rename_index(index, name)
-        assert renamed.name == name
-
-
 class TestSeriesMinMax:
     @mark.parametrize(
         ("x_v", "y_v", "dtype", "expected_min_v", "expected_max_v"),
@@ -365,25 +486,25 @@ class TestSeriesMinMax:
             param(
                 TIMESTAMP_MIN_AS_DATE,
                 TIMESTAMP_MAX_AS_DATE,
-                dt64ns,
+                datetime64ns,
                 TIMESTAMP_MIN_AS_DATE,
                 TIMESTAMP_MAX_AS_DATE,
             ),
             param(
                 TIMESTAMP_MIN_AS_DATE,
                 NaT,
-                dt64ns,
+                datetime64ns,
                 TIMESTAMP_MIN_AS_DATE,
                 TIMESTAMP_MIN_AS_DATE,
             ),
             param(
                 NaT,
                 TIMESTAMP_MAX_AS_DATE,
-                dt64ns,
+                datetime64ns,
                 TIMESTAMP_MAX_AS_DATE,
                 TIMESTAMP_MAX_AS_DATE,
             ),
-            param(NaT, NaT, dt64ns, NaT, NaT),
+            param(NaT, NaT, datetime64ns, NaT, NaT),
         ],
     )
     def test_main(
@@ -416,18 +537,17 @@ class TestSeriesMinMax:
     @mark.parametrize("func", [param(series_min), param(series_max)])
     def test_error(self, *, func: Callable[[SeriesA, SeriesA], SeriesA]) -> None:
         x = Series(data=nan, dtype=float)
-        y = Series(data=NA, dtype=Int64)  # type: ignore
-        with raises(SeriesMinMaxError):
+        y = Series(data=NA, dtype=Int64)
+        with raises(
+            SeriesMinMaxError,
+            match=re.compile(
+                r"Series .* and .* must have the same dtype; got .* and .*\.",
+                flags=DOTALL,
+            ),
+        ):
             _ = func(x, y)
 
 
-class TestSortIndex:
-    @given(index=int_indexes())
-    def test_main(self, *, index: IndexI) -> None:
-        sorted_ = sort_index(index)
-        assert_index_equal(sorted_, cast(Any, index.sort_values()))
-
-
 class TestTimestampMinMaxAsDate:
     def test_min(self) -> None:
         date = TIMESTAMP_MIN_AS_DATE
@@ -510,7 +630,7 @@ class TestToNumpy:
             param(True, boolean, True, object),
             param(False, boolean, False, object),
             param(NA, boolean, None, object),
-            param(TODAY_UTC, dt64ns, TODAY_UTC, dt64ns),
+            param(TODAY_UTC, datetime64ns, TODAY_UTC, datetime64ns),
             param(0, int, 0, int),
             param(0, Int64, 0, object),
             param(NA, Int64, None, object),
@@ -526,3 +646,42 @@ class TestToNumpy:
         result = to_numpy(series)
         expected = array([array_v], dtype=array_d)
         assert_equal(result, expected)
+
+
+class TestUnionIndexes:
+    @given(name=text_ascii() | none())
+    def test_first_named(self, *, name: str | None) -> None:
+        left = Index([1, 2, 3], name=name)
+        right = Index([2, 3, 4])
+        result1 = union_indexes(left, right)
+        result2 = union_indexes(right, left)
+        expected = Index([1, 2, 3, 4], name=name)
+        assert_index_equal(result1, expected)
+        assert_index_equal(result2, expected)
+
+    @given(lname=text_ascii(), rname=text_ascii())
+    def test_both_named_taking_first(self, *, lname: str, rname: str) -> None:
+        left = Index([1, 2, 3], name=lname)
+        right = Index([2, 3, 4], name=rname)
+        result = union_indexes(left, right, names="first")
+        expected = Index([1, 2, 3, 4], name=lname)
+        assert_index_equal(result, expected)
+
+    @given(lname=text_ascii(), rname=text_ascii())
+    def test_both_named_taking_last(self, *, lname: str, rname: str) -> None:
+        left = Index([1, 2, 3], name=lname)
+        right = Index([2, 3, 4], name=rname)
+        result = union_indexes(left, right, names="last")
+        expected = Index([1, 2, 3, 4], name=rname)
+        assert_index_equal(result, expected)
+
+    @given(lname=text_ascii(), rname=text_ascii())
+    def test_both_named_error(self, *, lname: str, rname: str) -> None:
+        _ = assume(lname != rname)
+        left = Index([1, 2, 3], name=lname)
+        right = Index([2, 3, 4], name=rname)
+        with raises(
+            UnionIndexesError,
+            match=r"Indexes .* and .* must have the same name; got .* and .*\.",
+        ):
+            _ = union_indexes(left, right, names="raise")
