@@ -1,12 +1,10 @@
 from __future__ import annotations
 
-from collections.abc import Set as AbstractSet
-from typing import Any
+from typing import TYPE_CHECKING, Any, assert_never
 
 from hypothesis import given
 from hypothesis.strategies import sets
 from pytest import mark, param
-from typing_extensions import assert_never
 
 from utilities.hypothesis import text_ascii
 from utilities.platform import (
@@ -22,19 +20,22 @@ from utilities.platform import (
     maybe_yield_lower_case,
 )
 
+if TYPE_CHECKING:
+    from collections.abc import Set as AbstractSet
+
 
 class TestMaybeYieldLowerCase:
     @given(text=sets(text_ascii()))
     def test_main(self, *, text: AbstractSet[str]) -> None:
         result = set(maybe_yield_lower_case(text))
         match SYSTEM:
-            case System.windows:  # pragma: os-ne-windows
+            case System.windows:  # skipif-os-ne-windows
                 assert all(text == text.lower() for text in result)
-            case System.mac:  # pragma: os-ne-macos
+            case System.mac:  # skipif-os-ne-macos
                 assert all(text == text.lower() for text in result)
-            case System.linux:  # pragma: os-ne-linux
+            case System.linux:  # skipif-os-ne-linux
                 assert result == text
-            case _ as never:  # type: ignore
+            case _ as never:  # pyright: ignore[reportUnnecessaryComparison]
                 assert_never(never)
 
 
