@@ -1,11 +1,14 @@
 from __future__ import annotations
 
-from pathlib import Path
 from re import search
 from time import sleep
+from typing import TYPE_CHECKING
 
 from utilities.pyinstrument import profile
 
+if TYPE_CHECKING:
+    from pathlib import Path
+
 
 class TestProfile:
     def test_main(self, tmp_path: Path) -> None:
