@@ -1,6 +1,11 @@
 from __future__ import annotations
 
-from utilities.sys import VERSION_MAJOR_MINOR
+from utilities.sys import VERSION_MAJOR_MINOR, is_pytest
+
+
+class TestIsPytest:
+    def test_main(self) -> None:
+        assert is_pytest()
 
 
 class TestVersionMajorMinor:
