@@ -1,15 +1,17 @@
 from __future__ import annotations
 
-from collections.abc import Iterable
 from email.mime.application import MIMEApplication
 from email.mime.multipart import MIMEMultipart
 from email.mime.text import MIMEText
 from smtplib import SMTP
-from typing import Any
+from typing import TYPE_CHECKING
 
-from utilities.errors import redirect_error
-from utilities.pathvalidate import valid_path
-from utilities.types import IterableStrs, PathLike
+from utilities.pathlib import ensure_path
+
+if TYPE_CHECKING:
+    from collections.abc import Iterable
+
+    from utilities.types import IterableStrs, PathLike
 
 
 def send_email(
@@ -18,11 +20,12 @@ def send_email(
     /,
     *,
     subject: str | None = None,
-    contents: Any = None,
+    contents: str | None = None,
     subtype: str = "plain",
     host: str = "",
     port: int = 0,
     attachments: Iterable[PathLike] | None = None,
+    validate: bool = False,
 ) -> None:
     """Send an email."""
     message = MIMEMultipart()
@@ -31,26 +34,20 @@ def send_email(
     if subject is not None:
         message["Subject"] = subject
     if contents is not None:
-        if isinstance(contents, str):
-            text = MIMEText(contents, subtype)
-        else:
-            with redirect_error(ModuleNotFoundError, SendEmailError(f"{contents=}")):
-                from airium import Airium
-
-                if not isinstance(contents, Airium):
-                    raise SendEmailError(contents)
-                text = MIMEText(str(contents), "html")
+        text = MIMEText(contents, subtype)
         message.attach(text)
     if attachments is not None:
         for attachment in attachments:
-            _add_attachment(attachment, message)
+            _add_attachment(attachment, message, validate=validate)
     with SMTP(host=host, port=port) as smtp:
         _ = smtp.send_message(message)
 
 
-def _add_attachment(path: PathLike, message: MIMEMultipart, /) -> None:
+def _add_attachment(
+    path: PathLike, message: MIMEMultipart, /, *, validate: bool = False
+) -> None:
     """Add an attachment to an email."""
-    path = valid_path(path)
+    path = ensure_path(path, validate=validate)
     name = path.name
     with path.open(mode="rb") as fh:
         part = MIMEApplication(fh.read(), Name=name)
@@ -58,8 +55,7 @@ def _add_attachment(path: PathLike, message: MIMEMultipart, /) -> None:
     message.attach(part)
 
 
-class SendEmailError(Exception):
-    ...
+class SendEmailError(Exception): ...
 
 
 __all__ = ["SendEmailError", "send_email"]
