@@ -1,13 +1,17 @@
 from __future__ import annotations
 
-from collections.abc import Iterator
 from contextlib import contextmanager
+from dataclasses import dataclass
 from functools import partial as _partial
-from typing import Any, TypeVar
+from typing import TYPE_CHECKING, Any, TypeVar
 
 from typing_extensions import override
 
-from utilities.errors import redirect_error
+from utilities.iterables import one
+from utilities.text import ensure_str
+
+if TYPE_CHECKING:
+    from collections.abc import Iterator
 
 _T = TypeVar("_T")
 
@@ -25,16 +29,20 @@ class partial(_partial[_T]):  # noqa: N801
 @contextmanager
 def redirect_empty_reduce() -> Iterator[None]:
     """Redirect to the `EmptyReduceError`."""
-    with redirect_error(
-        TypeError,
-        EmptyReduceError,
-        match=r"reduce\(\) of empty iterable with no initial value",
-    ):
+    try:
         yield
+    except TypeError as error:
+        arg = ensure_str(one(error.args))
+        if arg == "reduce() of empty iterable with no initial value":
+            raise EmptyReduceError from None
+        raise
 
 
+@dataclass(kw_only=True)
 class EmptyReduceError(Exception):
-    ...
+    @override
+    def __str__(self) -> str:
+        return "reduce() must not be called over an empty iterable, or must have an initial value."
 
 
 __all__ = ["EmptyReduceError", "partial", "redirect_empty_reduce"]
