@@ -1,13 +1,17 @@
 from __future__ import annotations
 
-from utilities.pathvalidate import valid_path_cwd
+from typing import TYPE_CHECKING
+
+from utilities.pathlib import PWD
 from utilities.re import extract_groups
 from utilities.subprocess import get_shell_output
-from utilities.types import PathLike
+
+if TYPE_CHECKING:
+    from utilities.types import PathLike
 
 
 def get_hatch_version(
-    *, cwd: PathLike = valid_path_cwd(), activate: PathLike | None = None
+    *, cwd: PathLike = PWD, activate: PathLike | None = None
 ) -> tuple[int, int, int]:
     """Get the `hatch` version."""
     version = get_shell_output("hatch version", cwd=cwd, activate=activate).strip("\n")
