@@ -1,18 +1,22 @@
 from __future__ import annotations
 
 from contextlib import ExitStack
-from dataclasses import dataclass, field
+from dataclasses import dataclass, field, replace
 from itertools import chain
-from types import TracebackType
-from typing import Any
+from typing import TYPE_CHECKING, Any, Self
 
 from utilities.ipython import check_ipython_class
 
+if TYPE_CHECKING:
+    from types import TracebackType
+
 
 def is_jupyter() -> bool:
     """Check if `jupyter` is running."""
     try:
-        from ipykernel.zmqshell import ZMQInteractiveShell  # type: ignore
+        from ipykernel.zmqshell import (  # pyright: ignore[reportMissingImports]
+            ZMQInteractiveShell,
+        )
     except ImportError:
         return False
     return check_ipython_class(ZMQInteractiveShell)  # pragma: no cover
@@ -22,23 +26,23 @@ _DEFAULT_ROWS = 7
 _DEFAULT_COLS = 100
 
 
-@dataclass(frozen=True)
+@dataclass
 class _Show:
     """Context manager which adjusts the display of NDFrames."""
 
-    dp: int | None = None
-    rows: int | None = _DEFAULT_ROWS
-    columns: int | None = _DEFAULT_COLS
-    stack: ExitStack = field(default_factory=ExitStack)
+    rows: int | None = field(default=_DEFAULT_ROWS)
+    columns: int | None = field(default=_DEFAULT_COLS, kw_only=True)
+    dp: int | None = field(default=None, kw_only=True)
+    stack: ExitStack = field(default_factory=ExitStack, kw_only=True)
 
     def __call__(
         self,
+        rows: int | None = _DEFAULT_ROWS,
         *,
         dp: int | None = None,
-        rows: int | None = _DEFAULT_ROWS,
         columns: int | None = _DEFAULT_COLS,
-    ) -> _Show:
-        return _Show(dp=dp, rows=rows, columns=columns)
+    ) -> Self:
+        return replace(self, rows=rows, dp=dp, columns=columns)
 
     def __enter__(self) -> None:
         self._enter_pandas()
