@@ -1,26 +1,29 @@
 from __future__ import annotations
 
-from collections.abc import Callable, Iterable, Iterator
 from contextlib import contextmanager
 from locale import LC_CTYPE, LC_NUMERIC, getlocale, setlocale
 from locale import atof as _atof
 from locale import atoi as _atoi
-
-from typing_extensions import assert_never
+from typing import TYPE_CHECKING, assert_never
 
 from utilities.platform import SYSTEM, System
 
+if TYPE_CHECKING:
+    from collections.abc import Callable, Iterable, Iterator
+
+    from utilities.iterables import MaybeIterable
+
 
 def get_locale_for_platform(locale: str, /) -> str:
     """Get the platform-dependent locale."""
     match SYSTEM:
-        case System.windows:  # pragma: os-ne-windows
+        case System.windows:  # skipif-os-ne-windows
             return locale
-        case System.mac:  # pragma: os-ne-macos
+        case System.mac:  # skipif-os-ne-macos
             return locale
-        case System.linux:  # pragma: os-ne-linux
+        case System.linux:  # skipif-os-ne-linux
             return f"{locale}.utf8"
-        case _ as never:  # type: ignore
+        case _ as never:  # pyright: ignore[reportUnnecessaryComparison]
             assert_never(never)
 
 
@@ -38,14 +41,14 @@ def atof(
     text: str,
     /,
     *,
-    locale: str | Iterable[str | None] | None = None,
+    locale: MaybeIterable[str | None] = None,
     func: Callable[[str], float] = float,
 ) -> float:
     with override_locale(category=LC_NUMERIC, locale=locale):
         return _atof(text, func=func)
 
 
-def atoi(text: str, /, *, locale: str | Iterable[str | None] | None = None) -> float:
+def atoi(text: str, /, *, locale: MaybeIterable[str | None] = None) -> float:
     with override_locale(category=LC_NUMERIC, locale=locale):
         return _atoi(text)
 
