@@ -1,14 +1,16 @@
 from __future__ import annotations
 
 from dataclasses import dataclass
-from math import isclose, isfinite, isnan
-from typing import Annotated, Any, cast
+from math import isclose, isfinite, isnan, log10
+from typing import Annotated, Literal, overload
 
-from beartype.vale import Is
 from typing_extensions import override
 
 from utilities.errors import ImpossibleCaseError
 
+MAX_LONG = 2**31 - 1
+MIN_LONG = -(2**31)
+
 # functions
 
 
@@ -356,52 +358,87 @@ def _is_close(
     )
 
 
+def number_of_decimals(x: float, /, *, max_decimals: int = 20) -> int:
+    """Get the number of decimals."""
+    _, frac = divmod(x, 1)
+    results = (
+        s for s in range(max_decimals + 1) if _number_of_decimals_check_scale(frac, s)
+    )
+    try:
+        return next(results)
+    except StopIteration:
+        raise NumberOfDecimalsError(x=x, max_decimals=max_decimals) from None
+
+
+def _number_of_decimals_check_scale(frac: float, scale: int, /) -> bool:
+    scaled = 10**scale * frac
+    return isclose(scaled, round(scaled))
+
+
+@dataclass(kw_only=True)
+class NumberOfDecimalsError(Exception):
+    x: float
+    max_decimals: int
+
+    @override
+    def __str__(self) -> str:
+        return f"Could not determine number of decimals of {self.x} (up to {self.max_decimals})"
+
+
+@overload
+def order_of_magnitude(x: float, /, *, round_: Literal[True]) -> int: ...
+@overload
+def order_of_magnitude(x: float, /, *, round_: bool = False) -> float: ...
+def order_of_magnitude(x: float, /, *, round_: bool = False) -> float:
+    """Get the order of magnitude of a number."""
+    result = log10(abs(x))
+    return round(result) if round_ else result
+
+
 # annotations
 
 
 # int
-IntNeg = Annotated[int, Is[cast(Any, is_negative)]]
-IntNonNeg = Annotated[int, Is[cast(Any, is_non_negative)]]
-IntNonPos = Annotated[int, Is[cast(Any, is_non_positive)]]
-IntNonZr = Annotated[int, Is[cast(Any, is_non_zero)]]
-IntPos = Annotated[int, Is[cast(Any, is_positive)]]
-IntZr = Annotated[int, Is[cast(Any, is_zero)]]
+IntNeg = Annotated[int, is_negative]
+IntNonNeg = Annotated[int, is_non_negative]
+IntNonPos = Annotated[int, is_non_positive]
+IntNonZr = Annotated[int, is_non_zero]
+IntPos = Annotated[int, is_positive]
+IntZr = Annotated[int, is_zero]
 
 # float
-FloatFin = Annotated[float, Is[cast(Any, is_finite)]]
-FloatFinInt = Annotated[float, Is[cast(Any, is_finite_and_integral)]]
-FloatFinIntNan = Annotated[float, Is[cast(Any, is_finite_and_integral_or_nan)]]
-FloatFinNeg = Annotated[float, Is[cast(Any, is_finite_and_negative)]]
-FloatFinNegNan = Annotated[float, Is[cast(Any, is_finite_and_negative_or_nan)]]
-FloatFinNonNeg = Annotated[float, Is[cast(Any, is_finite_and_non_negative)]]
-FloatFinNonNegNan = Annotated[float, Is[cast(Any, is_finite_and_non_negative_or_nan)]]
-FloatFinNonPos = Annotated[float, Is[cast(Any, is_finite_and_non_positive)]]
-FloatFinNonPosNan = Annotated[float, Is[cast(Any, is_finite_and_non_positive_or_nan)]]
-FloatFinNonZr = Annotated[float, Is[cast(Any, is_finite_and_non_zero)]]
-FloatFinNonZrNan = Annotated[float, Is[cast(Any, is_finite_and_non_zero_or_nan)]]
-FloatFinPos = Annotated[float, Is[cast(Any, is_finite_and_positive)]]
-FloatFinPosNan = Annotated[float, Is[cast(Any, is_finite_and_positive_or_nan)]]
-FloatFinNan = Annotated[float, Is[cast(Any, is_finite_or_nan)]]
-FloatInt = Annotated[float, Is[cast(Any, is_integral)]]
-FloatIntNan = Annotated[float, Is[cast(Any, is_integral_or_nan)]]
-FloatNeg = Annotated[float, Is[cast(Any, is_negative)]]
-FloatNegNan = Annotated[float, Is[cast(Any, is_negative_or_nan)]]
-FloatNonNeg = Annotated[float, Is[cast(Any, is_non_negative)]]
-FloatNonNegNan = Annotated[float, Is[cast(Any, is_non_negative_or_nan)]]
-FloatNonPos = Annotated[float, Is[cast(Any, is_non_positive)]]
-FloatNonPosNan = Annotated[float, Is[cast(Any, is_non_positive_or_nan)]]
-FloatNonZr = Annotated[float, Is[cast(Any, is_non_zero)]]
-FloatNonZrNan = Annotated[float, Is[cast(Any, is_non_zero_or_nan)]]
-FloatPos = Annotated[float, Is[cast(Any, is_positive)]]
-FloatPosNan = Annotated[float, Is[cast(Any, is_positive_or_nan)]]
-FloatZr = Annotated[float, Is[cast(Any, is_zero)]]
-FloatZrFinNonMic = Annotated[float, Is[cast(Any, is_zero_or_finite_and_non_micro)]]
-FloatZrFinNonMicNan = Annotated[
-    float, Is[cast(Any, is_zero_or_finite_and_non_micro_or_nan)]
-]
-FloatZrNan = Annotated[float, Is[cast(Any, is_zero_or_nan)]]
-FloatZrNonMic = Annotated[float, Is[cast(Any, is_zero_or_non_micro)]]
-FloatZrNonMicNan = Annotated[float, Is[cast(Any, is_zero_or_non_micro_or_nan)]]
+FloatFin = Annotated[float, is_finite]
+FloatFinInt = Annotated[float, is_finite_and_integral]
+FloatFinIntNan = Annotated[float, is_finite_and_integral_or_nan]
+FloatFinNeg = Annotated[float, is_finite_and_negative]
+FloatFinNegNan = Annotated[float, is_finite_and_negative_or_nan]
+FloatFinNonNeg = Annotated[float, is_finite_and_non_negative]
+FloatFinNonNegNan = Annotated[float, is_finite_and_non_negative_or_nan]
+FloatFinNonPos = Annotated[float, is_finite_and_non_positive]
+FloatFinNonPosNan = Annotated[float, is_finite_and_non_positive_or_nan]
+FloatFinNonZr = Annotated[float, is_finite_and_non_zero]
+FloatFinNonZrNan = Annotated[float, is_finite_and_non_zero_or_nan]
+FloatFinPos = Annotated[float, is_finite_and_positive]
+FloatFinPosNan = Annotated[float, is_finite_and_positive_or_nan]
+FloatFinNan = Annotated[float, is_finite_or_nan]
+FloatInt = Annotated[float, is_integral]
+FloatIntNan = Annotated[float, is_integral_or_nan]
+FloatNeg = Annotated[float, is_negative]
+FloatNegNan = Annotated[float, is_negative_or_nan]
+FloatNonNeg = Annotated[float, is_non_negative]
+FloatNonNegNan = Annotated[float, is_non_negative_or_nan]
+FloatNonPos = Annotated[float, is_non_positive]
+FloatNonPosNan = Annotated[float, is_non_positive_or_nan]
+FloatNonZr = Annotated[float, is_non_zero]
+FloatNonZrNan = Annotated[float, is_non_zero_or_nan]
+FloatPos = Annotated[float, is_positive]
+FloatPosNan = Annotated[float, is_positive_or_nan]
+FloatZr = Annotated[float, is_zero]
+FloatZrFinNonMic = Annotated[float, is_zero_or_finite_and_non_micro]
+FloatZrFinNonMicNan = Annotated[float, is_zero_or_finite_and_non_micro_or_nan]
+FloatZrNan = Annotated[float, is_zero_or_nan]
+FloatZrNonMic = Annotated[float, is_zero_or_non_micro]
+FloatZrNonMicNan = Annotated[float, is_zero_or_non_micro_or_nan]
 
 
 # checks
@@ -427,21 +464,21 @@ def check_integer(
         raise _CheckIntegerMaxError(n=n, max_=max)
 
 
-@dataclass(frozen=True, kw_only=True, slots=True)
+@dataclass(kw_only=True)
 class CheckIntegerError(Exception):
     n: int
 
 
-@dataclass(frozen=True, kw_only=True, slots=True)
+@dataclass(kw_only=True)
 class _CheckIntegerEqualError(CheckIntegerError):
     equal: int
 
     @override
     def __str__(self) -> str:
-        return "Integer must be equal to {}; got {}".format(self.equal, self.n)
+        return f"Integer must be equal to {self.equal}; got {self.n}"
 
 
-@dataclass(frozen=True, kw_only=True, slots=True)
+@dataclass(kw_only=True)
 class _CheckIntegerEqualOrApproxError(CheckIntegerError):
     equal_or_approx: int | tuple[int, float]
 
@@ -449,31 +486,33 @@ class _CheckIntegerEqualOrApproxError(CheckIntegerError):
     def __str__(self) -> str:
         match self.equal_or_approx:
             case target, error:
-                desc = "approximately equal to {} (error {:%})".format(target, error)
+                desc = f"approximately equal to {target} (error {error:%})"
             case target:
-                desc = "equal to {}".format(target)
-        return "Integer must be {}; got {}".format(desc, self.n)
+                desc = f"equal to {target}"
+        return f"Integer must be {desc}; got {self.n}"
 
 
-@dataclass(frozen=True, kw_only=True, slots=True)
+@dataclass(kw_only=True)
 class _CheckIntegerMinError(CheckIntegerError):
     min_: int
 
     @override
     def __str__(self) -> str:
-        return "Integer must be at least {}; got {}".format(self.min_, self.n)
+        return f"Integer must be at least {self.min_}; got {self.n}"
 
 
-@dataclass(frozen=True, kw_only=True, slots=True)
+@dataclass(kw_only=True)
 class _CheckIntegerMaxError(CheckIntegerError):
     max_: int
 
     @override
     def __str__(self) -> str:
-        return "Integer must be at most {}; got {}".format(self.max_, self.n)
+        return f"Integer must be at most {self.max_}; got {self.n}"
 
 
 __all__ = [
+    "MAX_LONG",
+    "MIN_LONG",
     "CheckIntegerError",
     "FloatFin",
     "FloatFinInt",
@@ -556,4 +595,6 @@ __all__ = [
     "is_zero_or_nan",
     "is_zero_or_non_micro",
     "is_zero_or_non_micro_or_nan",
+    "number_of_decimals",
+    "order_of_magnitude",
 ]
