@@ -1,12 +1,21 @@
 from __future__ import annotations
 
-from collections.abc import Iterator, Mapping
 from contextlib import contextmanager, suppress
 from dataclasses import dataclass
 from os import cpu_count, environ, getenv
+from typing import TYPE_CHECKING, assert_never
 
 from typing_extensions import override
 
+from utilities.iterables import (
+    _OneStrCaseInsensitiveEmptyError,
+    _OneStrCaseSensitiveEmptyError,
+    one_str,
+)
+
+if TYPE_CHECKING:
+    from collections.abc import Iterator, Mapping
+
 
 def get_cpu_count() -> int:
     """Get the CPU count."""
@@ -16,7 +25,7 @@ def get_cpu_count() -> int:
     return count
 
 
-@dataclass(frozen=True, kw_only=True, slots=True)
+@dataclass(kw_only=True)
 class GetCPUCountError(Exception):
     @override
     def __str__(self) -> str:
@@ -26,6 +35,22 @@ class GetCPUCountError(Exception):
 CPU_COUNT = get_cpu_count()
 
 
+def get_env_var(key: str, /, *, case_sensitive: bool = True) -> str | None:
+    """Get an environment variable."""
+    match case_sensitive:
+        case True:
+            error = _OneStrCaseSensitiveEmptyError
+        case False:
+            error = _OneStrCaseInsensitiveEmptyError
+        case _ as never:  # pyright: ignore[reportUnnecessaryComparison]
+            assert_never(never)
+    try:
+        key_use = one_str(environ, key, case_sensitive=case_sensitive)
+    except error:
+        return None
+    return environ[key_use]
+
+
 @contextmanager
 def temp_environ(
     env: Mapping[str, str | None] | None = None, **env_kwargs: str | None
@@ -49,4 +74,10 @@ def temp_environ(
         apply(prev)
 
 
-__all__ = ["CPU_COUNT", "GetCPUCountError", "get_cpu_count", "temp_environ"]
+__all__ = [
+    "CPU_COUNT",
+    "GetCPUCountError",
+    "get_cpu_count",
+    "get_env_var",
+    "temp_environ",
+]
