@@ -1,17 +1,20 @@
 from __future__ import annotations
 
-from collections.abc import Iterator
 from dataclasses import dataclass
-from enum import Enum, unique
+from enum import StrEnum, unique
 from platform import system
+from typing import TYPE_CHECKING, assert_never
 
-from typing_extensions import assert_never, override
+from typing_extensions import override
 
-from utilities.types import IterableStrs
+if TYPE_CHECKING:
+    from collections.abc import Iterator
+
+    from utilities.types import IterableStrs
 
 
 @unique
-class System(str, Enum):
+class System(StrEnum):
     """An enumeration of the systems."""
 
     windows = "windows"
@@ -22,25 +25,23 @@ class System(str, Enum):
 def get_system() -> System:
     """Get the system/OS name."""
     sys = system()
-    if sys == "Windows":  # pragma: os-ne-windows
+    if sys == "Windows":  # skipif-os-ne-windows
         return System.windows
-    if sys == "Darwin":  # pragma: os-ne-macos
+    if sys == "Darwin":  # skipif-os-ne-macos
         return System.mac
-    if sys == "Linux":  # pragma: os-ne-linux
+    if sys == "Linux":  # skipif-os-ne-linux
         return System.linux
     raise GetSystemError(sys=sys)  # pragma: no cover
 
 
-@dataclass(frozen=True, kw_only=True, slots=True)
+@dataclass(kw_only=True)
 class GetSystemError(Exception):
     sys: str
 
     @override
     def __str__(self) -> str:
         return (  # pragma: no cover
-            "System must be one of Windows, Darwin, Linux; got {!r} instead".format(
-                self.sys
-            )
+            f"System must be one of Windows, Darwin, Linux; got {self.sys!r} instead"
         )
 
 
@@ -56,18 +57,17 @@ IS_NOT_LINUX = not IS_LINUX
 def maybe_yield_lower_case(text: IterableStrs, /) -> Iterator[str]:
     """Yield lower-cased text if the platform is case-insentive."""
     match SYSTEM:
-        case System.windows:  # pragma: os-ne-windows
+        case System.windows:  # skipif-os-ne-windows
             yield from (t.lower() for t in text)
-        case System.mac:  # pragma: os-ne-macos
+        case System.mac:  # skipif-os-ne-macos
             yield from (t.lower() for t in text)
-        case System.linux:  # pragma: os-ne-linux
+        case System.linux:  # skipif-os-ne-linux
             yield from text
-        case _ as never:  # type: ignore
+        case _ as never:  # pyright: ignore[reportUnnecessaryComparison]
             assert_never(never)
 
 
 __all__ = [
-    "GetSystemError",
     "IS_LINUX",
     "IS_MAC",
     "IS_NOT_LINUX",
@@ -75,6 +75,7 @@ __all__ = [
     "IS_NOT_WINDOWS",
     "IS_WINDOWS",
     "SYSTEM",
+    "GetSystemError",
     "System",
     "get_system",
     "maybe_yield_lower_case",
