@@ -1,9 +1,9 @@
 from __future__ import annotations
 
 from dataclasses import dataclass
-from pathlib import Path
+from pathlib import Path  # noqa: TCH003
 
-from utilities.pathvalidate import valid_path
+from utilities.pathlib import ensure_path
 from utilities.typed_settings import click_field
 
 
@@ -12,5 +12,5 @@ class Config:
     """Settings for the `monitor_memory` script."""
 
     path: Path = click_field(
-        default=valid_path("input.csv"), param_decls=("-p", "--path")
+        default=ensure_path("input.csv"), param_decls=("-p", "--path")
     )
