@@ -2,25 +2,27 @@ from __future__ import annotations
 
 import dataclasses
 import datetime as dt
-from collections.abc import Iterator
 from contextlib import contextmanager
 from csv import DictWriter
 from dataclasses import fields
-from pathlib import Path
+from pathlib import Path  # noqa: TCH003
 from time import sleep
-from typing import Any, cast
+from typing import TYPE_CHECKING, Any, assert_never, cast
 
 from click import command
 from loguru import logger
 from psutil import swap_memory, virtual_memory
-from typing_extensions import assert_never
 
-from utilities.datetime import UTC, get_now
+from utilities.datetime import get_now
 from utilities.loguru import setup_loguru
 from utilities.platform import SYSTEM, System
 from utilities.scripts.monitor_memory.classes import Config, Item
 from utilities.timer import Timer
 from utilities.typed_settings import click_options
+from utilities.zoneinfo import UTC
+
+if TYPE_CHECKING:
+    from collections.abc import Iterator
 
 _CONFIG = Config()
 
@@ -57,34 +59,34 @@ def _monitor_memory(
 @contextmanager
 def _yield_writer(
     *, path: Path = _CONFIG.path, mode: str = "r"
-) -> Iterator[DictWriter[Any]]:
+) -> Iterator[DictWriter]:
     fieldnames = [f.name for f in fields(cast(Any, Item))]
     with path.open(mode=mode) as fh:
         yield DictWriter(fh, fieldnames=fieldnames)
 
 
-def _get_memory_usage() -> Item:
+def _get_memory_usage() -> Item:  # pyright: ignore[reportInvalidTypeForm]
     virtual = cast(Any, virtual_memory())
     virtual_kwargs: dict[str, Any] = {}
     match SYSTEM:
-        case System.windows:  # pragma: os-ne-windows
+        case System.windows:  # skipif-os-ne-windows
             pass
-        case System.mac:  # pragma: os-ne-macos
+        case System.mac:  # skipif-os-ne-macos
             virtual_kwargs["virtual_active"] = virtual.active
             virtual_kwargs["virtual_inactive"] = virtual.inactive
             virtual_kwargs["virtual_wired"] = virtual.wired
-        case System.linux:  # pragma: os-ne-linux
+        case System.linux:  # skipif-os-ne-linux
             virtual_kwargs["virtual_active"] = virtual.active
             virtual_kwargs["virtual_inactive"] = virtual.inactive
             virtual_kwargs["virtual_buffers"] = virtual.buffers
             virtual_kwargs["virtual_cached"] = virtual.cached
             virtual_kwargs["virtual_shared"] = virtual.shared
             virtual_kwargs["virtual_slab"] = virtual.slab
-        case _ as never:  # type: ignore
+        case _ as never:  # pyright: ignore[reportUnnecessaryComparison]
             assert_never(never)
     swap = swap_memory()
     return Item(
-        datetime=get_now(tz=UTC),
+        datetime=get_now(time_zone=UTC),
         virtual_total=virtual.total,
         virtual_available=virtual.available,
         virtual_percent=virtual.percent,
