@@ -1,26 +1,26 @@
 from __future__ import annotations
 
-import datetime as dt
 from dataclasses import dataclass
-from pathlib import Path
-from typing import Optional
+from pathlib import Path  # noqa: TCH003
+from typing import TYPE_CHECKING, assert_never
 
-from typing_extensions import assert_never
-
-from utilities.pathvalidate import valid_path
+from utilities.pathlib import ensure_path
 from utilities.platform import SYSTEM, System
 from utilities.typed_settings import click_field
 
+if TYPE_CHECKING:
+    import datetime as dt
+
 
 @dataclass(frozen=True)
 class Config:
     """Settings for the `monitor_memory` script."""
 
     path: Path = click_field(
-        default=valid_path("memory.csv"), param_decls=("-p", "--path")
+        default=ensure_path("memory.csv"), param_decls=("-p", "--path")
     )
     freq: int = click_field(default=60, help="in seconds", param_decls=("-f", "--freq"))
-    duration: Optional[int] = click_field(  # noqa: UP007
+    duration: int | None = click_field(
         default=None, help="in seconds", param_decls=("-d", "--duration")
     )
 
@@ -89,11 +89,11 @@ class ItemLinux:
 
 
 match SYSTEM:
-    case System.windows:  # pragma: os-ne-windows
+    case System.windows:  # skipif-os-ne-windows
         Item = ItemWindows
-    case System.mac:  # pragma: os-ne-macos
+    case System.mac:  # skipif-os-ne-macos
         Item = ItemMacOS
-    case System.linux:  # pragma: os-ne-linux
+    case System.linux:  # skipif-os-ne-linux
         Item = ItemLinux
-    case _ as never:  # type: ignore
+    case _ as never:  # pyright: ignore[reportUnnecessaryComparison]
         assert_never(never)
