@@ -1,16 +1,19 @@
 from __future__ import annotations
 
 from pathlib import Path
+from typing import TYPE_CHECKING
 
 from click import command
 from loguru import logger
 
 from utilities.loguru import setup_loguru
-from utilities.pathvalidate import valid_path
+from utilities.pathlib import ensure_path
 from utilities.scripts.pypi_server.classes import Config
 from utilities.subprocess import run_accept_address_in_use
 from utilities.typed_settings import click_options
-from utilities.types import PathLike
+
+if TYPE_CHECKING:
+    from utilities.types import PathLike
 
 _CONFIG = Config()
 
@@ -32,7 +35,7 @@ def main(config: Config, /) -> None:
 
 
 def _check_password_file(*, path_password: PathLike = _CONFIG.path_password) -> None:
-    if not valid_path(path_password).exists():
+    if not ensure_path(path_password).exists():
         msg = f"{path_password=!s}"
         raise FileNotFoundError(msg)
 
