@@ -1,24 +1,27 @@
 from __future__ import annotations
 
-from collections.abc import Iterator, Mapping
 from functools import partial
 from itertools import chain, repeat, starmap
 from re import MULTILINE, escape, search
 from subprocess import PIPE, CalledProcessError, check_output
-from typing import Any
+from typing import TYPE_CHECKING, Any
 
 from utilities.errors import redirect_error
-from utilities.more_itertools import OneError, one
+from utilities.iterables import OneError, one
 from utilities.os import temp_environ
-from utilities.pathvalidate import valid_path, valid_path_cwd
-from utilities.types import IterableStrs, PathLike
+from utilities.pathlib import PWD, ensure_path
+
+if TYPE_CHECKING:
+    from collections.abc import Iterator, Mapping
+
+    from utilities.types import IterableStrs, PathLike
 
 
 def get_shell_output(
     cmd: str,
     /,
     *,
-    cwd: PathLike = valid_path_cwd(),
+    cwd: PathLike = PWD,
     activate: PathLike | None = None,
     env: Mapping[str, str | None] | None = None,
 ) -> str:
@@ -26,30 +29,23 @@ def get_shell_output(
 
     Optionally, activate a virtual environment if necessary.
     """
-    cwd = valid_path(cwd)
+    cwd = ensure_path(cwd)
     if activate is not None:
         with redirect_error(OneError, GetShellOutputError(f"{cwd=}")):
             activate = one(cwd.rglob("activate"))
-        cmd = f"source {activate}; {cmd}"  # pragma: os-ne-windows
+        cmd = f"source {activate}; {cmd}"  # skipif-os-ne-windows
 
     with temp_environ(env):
-        return check_output(
-            cmd,
-            stderr=PIPE,
-            shell=True,  # noqa: S602
-            cwd=cwd,
-            text=True,
-        )
+        return check_output(cmd, stderr=PIPE, shell=True, cwd=cwd, text=True)  # noqa: S602
 
 
-class GetShellOutputError(Exception):
-    ...
+class GetShellOutputError(Exception): ...
 
 
 def run_accept_address_in_use(args: IterableStrs, /, *, exist_ok: bool) -> None:
     """Run a command, accepting the 'address already in use' error."""
     try:  # pragma: no cover
-        _ = check_output(list(args), stderr=PIPE, text=True)  # noqa: S603
+        _ = check_output(list(args), stderr=PIPE, text=True)
     except CalledProcessError as error:  # pragma: no cover
         pattern = _address_already_in_use_pattern()
         try:
@@ -75,27 +71,27 @@ def _address_already_in_use_pattern() -> str:
 
 def tabulate_called_process_error(error: CalledProcessError, /) -> str:
     """Tabulate the components of a CalledProcessError."""
-    mapping = {  # pragma: os-ne-windows
+    mapping = {  # skipif-os-ne-windows
         "cmd": error.cmd,
         "returncode": error.returncode,
         "stdout": error.stdout,
         "stderr": error.stderr,
     }
-    max_key_len = max(map(len, mapping))  # pragma: os-ne-windows
-    tabulate = partial(_tabulate, buffer=max_key_len + 1)  # pragma: os-ne-windows
-    return "\n".join(starmap(tabulate, mapping.items()))  # pragma: os-ne-windows
+    max_key_len = max(map(len, mapping))  # skipif-os-ne-windows
+    tabulate = partial(_tabulate, buffer=max_key_len + 1)  # skipif-os-ne-windows
+    return "\n".join(starmap(tabulate, mapping.items()))  # skipif-os-ne-windows
 
 
 def _tabulate(key: str, value: Any, /, *, buffer: int) -> str:
-    template = f"{{:{buffer}}}{{}}"  # pragma: os-ne-windows
+    template = f"{{:{buffer}}}{{}}"  # skipif-os-ne-windows
 
-    def yield_lines() -> Iterator[str]:  # pragma: os-ne-windows
+    def yield_lines() -> Iterator[str]:  # skipif-os-ne-windows
         keys = chain([key], repeat(buffer * " "))
         value_lines = str(value).splitlines()
         for k, v in zip(keys, value_lines, strict=False):
             yield template.format(k, v)
 
-    return "\n".join(yield_lines())  # pragma: os-ne-windows
+    return "\n".join(yield_lines())  # skipif-os-ne-windows
 
 
 __all__ = [
